pub struct LawUpgradeStep {
pub level: i64,
pub required_copies: PositiveI64,
}Expand description
Cost of raising ONE law from level - 1 to level, paid in RAW COPIES of
that same law. The level of a copy is irrelevant — copies are stock.
Fields
level: i64required_copies: PositiveI64Trait Implementations
Sourceimpl Clone for LawUpgradeStep
impl Clone for LawUpgradeStep
Sourcefn clone(&self) -> LawUpgradeStep
fn clone(&self) -> LawUpgradeStep
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LawUpgradeStep
impl Debug for LawUpgradeStep
Sourceimpl<'de> Deserialize<'de> for LawUpgradeStep
impl<'de> Deserialize<'de> for LawUpgradeStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LawUpgradeStep
impl JsonSchema for LawUpgradeStep
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for LawUpgradeStep
impl Serialize for LawUpgradeStep
Sourceimpl Tsify for LawUpgradeStep
impl Tsify for LawUpgradeStep
const DECL: &'static str = "/**\n * Cost of raising ONE law from `level - 1` to `level`, paid in RAW COPIES of\n * that same law. The level of a copy is irrelevant \u{2014} copies are stock.\n */\nexport interface LawUpgradeStep {\n level: number;\n required_copies: PositiveI64;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>